"""Linux Mint logo"""

from archey.colors import Colors

COLORS = [Colors.GREEN_BRIGHT, Colors.WHITE_BRIGHT]

# pylint: disable=line-too-long
LOGO = [
    """{c[0]} MMMMMMMMMMMMMMMMMMMMMMMMMmds+.     """,
    """{c[0]} MMm----::-://////////////oymNMd+`  """,
    """{c[0]} MMd      {c[1]}/++{c[0]}                -sNMd: """,
    """{c[0]} MMNso/`  {c[1]}dMM{c[0]}    {c[1]}`.::-. .-::.`{c[0]} .hMN:""",
    """{c[0]} ddddMMh  {c[1]}dMM{c[0]}   {c[1]}:hNMNMNhNMNMNh:`{c[0]} NMm""",
    """{c[0]}     NMm  {c[1]}dMM{c[0]}  {c[1]}.NMN/-+MMM+-/NMN`{c[0]} dMM""",
    """{c[0]}     NMm  {c[1]}dMM{c[0]}  {c[1]}-MMm{c[0]}  {c[1]}`MMM{c[0]}   {c[1]}dMM.{c[0]} dMM""",
    """{c[0]}     NMm  {c[1]}dMM{c[0]}  {c[1]}-MMm{c[0]}  {c[1]}`MMM{c[0]}   {c[1]}dMM.{c[0]} dMM""",
    """{c[0]}     NMm  {c[1]}dMM{c[0]}  {c[1]}.mmd{c[0]}  {c[1]}`mmm{c[0]}   {c[1]}yMM.{c[0]} dMM""",
    """{c[0]}     NMm  {c[1]}dMM`{c[0]}  {c[1]}..`{c[0]}  {c[1]}`...{c[0]}   {c[1]}ydm.{c[0]} dMM""",
    """{c[0]}     hMM-  {c[1]}+MMd/-------...-:sdds{c[0]} MMM""",
    """{c[0]}     -NMm-  {c[1]}:hNMNNNmdddddddddy/`{c[0]} dMM""",
    """{c[0]}      -dMNs-``{c[1]}-::::-------.``{c[0]}    dMM""",
    """{c[0]}       `/dMNmy+/:-------------:/yMMM""",
    """{c[0]}          ./ydNMMMMMMMMMMMMMMMMMMMMM""",
]
